//
//  ParcelDetailViewController.swift
//  RWPS
//
//  Created by Mic Pringle on 04/12/2014.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

import UIKit
import MapKit

class ParcelDetailViewController: UIViewController {
  
  @IBOutlet weak var mapView: MKMapView!
  @IBOutlet weak var itemNameLabel: UILabel!
  @IBOutlet weak var orderNoLabel: UILabel!
  @IBOutlet weak var supplierNameLabel: UILabel!
  @IBOutlet weak var locationLabel: UILabel!
  @IBOutlet weak var statusLabel: UILabel!
  @IBOutlet weak var deliveryDateLabel: UILabel!
  @IBOutlet weak var daysRemainingLabel: UILabel!
  
  var parcel: Parcel!
  lazy var deliveryDateFormatter: NSDateFormatter = {
    let dateFormatter = NSDateFormatter()
    dateFormatter.dateFormat = "d MMMM"
    return dateFormatter
  }()
  
  private let parcelAnnotation = MKPointAnnotation()
  
  // MARK: UIViewController
  
  override func viewWillAppear(animated: Bool) {
    super.viewWillAppear(animated)
    title = parcel.supplierName
    itemNameLabel.text = parcel.itemName
    orderNoLabel.text = parcel.orderNo
    supplierNameLabel.text = parcel.supplierName
    locationLabel.text = parcel.location
    statusLabel.text = parcel.status
    deliveryDateLabel.text = deliveryDateFormatter.stringFromDate(parcel.deliveryDate)
    let numberOfDaysRemaining = parcel.daysRemainingBeforeDelivery()
    let daysString = numberOfDaysRemaining == 1 ? "day" : "days"
    daysRemainingLabel.text = "\(numberOfDaysRemaining) \(daysString)"
    locateParcel()
  }
  
  override func viewDidAppear(animated: Bool) {
    super.viewDidAppear(animated)
    mapView.selectAnnotation(parcelAnnotation, animated: animated)
  }
  
  // MARK: Private
  
  func locateParcel() {
    let adjustedCoordinateRegion = mapView.regionThatFits(parcel.locationCoordinateRegion)
    parcelAnnotation.coordinate = parcel.locationCoordinate
    parcelAnnotation.title = parcel.location
    mapView.setRegion(adjustedCoordinateRegion, animated: true)
    mapView.addAnnotation(parcelAnnotation)
  }
  
}
